Module examples

Module examples 

Examples

Each example can be easily run by using command:

cargo run --example <example_name>

The list of all available examples can be found below

Modules

genai_custom
User defined GenAI client
simple
Simple Example
struct_output
Structured Output Example
tools_custom
Custom Agent Tool Implementation
tools_mcp
Using MCP Server tools
tools_web
Agent Tools and Web Search