Examples
Each example can be easily run by using command:
cargo run --example <example_name>The list of all available examples can be found below
Modules
- genai_
custom - User defined GenAI client
- simple
- Simple Example
- struct_
output - Structured Output Example
- tools_
custom - Custom Agent Tool Implementation
- tools_
mcp - Using MCP Server tools
- tools_
web - Agent Tools and Web Search